.\" 
.\" Copyright (c) 2003, 2004 Gordon D. Carrie.  All rights reserved.
.\" 
.\" Licensed under the Open Software License version 2.1
.\" 
.\" Please address questions and bug reports to user0@tkgeomap.org.
.\"
.\" @(#) $Id: geomap_awips.n,v 1.4 2004/09/22 22:37:16 tkgeomap Exp $
.\"
.TH geomap_awips n 2 Tcl "Tcl Extensions geomap_awips"
.SH NAME
geomap_awips \- package to access NWS/AWIPS map data with Tcl/Tkgeomap
.SH VERSION
2
.SH SYNOPSIS
.nf
\fBpackage require geomap_awips ?2?\fR
.sp
\fBgeomap::awips::county::read\fR \fIshapefile region\fR
\fBgeomap::awips::county::regexp\fR \fIexp ?nocase?\fR
\fBgeomap::awips::state::read\fR \fIshapefile\fR
.fi
.SH INTRODUCTION
The geomap_awips package provides procedures that read and manage data from
the U.S. National Weather Service map database at
http://www.nws.noaa.gov/geodata.  It is distributed with \fBtkgm_util\fR, a
set of utilities to use with tkgeomap.
.SH SYSTEM REQUIREMENTS
Loading \fBgeomap_awips\fR requires the following applications and libraries:
.RS
.TP
\fBtcl/tk\fR
Scripting language from http://dev.scriptics.com, version 8.3 or later.
.TP
\fBtkgeomap\fR
Tcl/Tk extension to Tcl/TK, from http://tkgeomap.sourceforge.net
.TP
\fBshptobin\fR
Application to transform shapefile data to a form readable in tkgeomap.
It is part of \fBtkgm_util\fR.
.TP
\fBdbfdump\fR
Application to retrieve shapefile database information.  It is part of
\fBshapelib\fR, from http://gdal.velocet.ca/projects/shapelib.
.RE
.SH PROCEDURES
.TP
\fBgeomap::awips::county::read\fR \fIshapefile ?region options?\fR
.RS
This procedure reads county outlines from the National Weather Service
"AWIPS Counties" shapefile.  \fIshapeFile\fR identifies the shapefile
downloaded from the NWS site.  It actually consists of three files named
\fIshapeFile\fB.dbf\fR, \fIshapeFile\fB.shp\fR, and \fIshapeFile\fB.shx\fR.
If present, \fIregion options\fR requests that only counties in the specified
region be loaded.  The following region specifiers are recognized:
.RS
.TP
\fB-all\fR
Loads all counties.  This is the default.
.TP
\fB-states\fR \fIstateList\fR
Loads counties in the specified states.  \fIstateList\fR must be a list of
two-letter state abbreviations.
.TP
\fB-bounds\fR {\fInorth east south west\fR}
Loads counties whose centers are in the given latitude-longitude box.
.RE
.RE

.RS
The \fBread\fR procedure will give each county it loads a unique identifier of
form \fBc\fIXXX\fR, where \fIXXX\fR is an integer.  This identifier will refer
to the following information:
.RS
.TP
\fBgeomap::awips::county::name(c\fIXXX\fB)\fR
Array element giving the name of county.
.TP
\fBgeomap::awips::county::state(c\fIXXX\fB)\fR
Array element giving the state in which the county is located, given as a two
letter abbreviation.
.TP
\fBgeomap::awips::county::fips(c\fIXXX\fB)\fR
Array element giving the fips code for the county.
.TP
\fBgeomap::awips::county::c\fIXXX\fR
A linearray created with the \fBgeomap::lnarr\fR command (see the
\fBtclgeomap\fR (n) man page) containing boundary for the county.
.TP
\fBgeomap::awips::county::center::c\fIXXX\fR
A place created with the \fBgeomap::place\fR command (see the \fBtclgeomap\fR
(n) man page) giving coordinates of a place inside the county, giving a rough
idea of its location.
.TP
\fBgeomap::awips::county::counties\fR
List of identifiers for loaded counties.
.RE
.RE

.RS
Return value is the number of counties loaded.
.RE
.TP
\fBgeomap::awips::county::regexp\fR \fIexp ?nocase?\fR
Searches the \fBgeomap::awips::county\fR namespace for counties whose names
match regular expression pattern \fIexp\fR.  Return value is a list of county
identifiers of form \fBc\fIXXX\fR.  If \fInocase\fR option is present and has
a Boolean value of true, then the search is case insenstive.
.TP
\fBgeomap::awips::state::read\fR \fIshapefile\fR
.RS
Loads state outlines from the NWS/AWIPS "U.S. States and Territories" shapefile.
\fIshapefile\fR identifies the shapefile downloaded from the NWS/AWIPS site.
It should consist of files \fIshapefile\fB.dbf\fR, \fIshapefile\fB.shp\fR,
\fIshapefile\fB.shx\fR.  Each state will be identified by its two letter
abbreviation \fIID\fR, which will refer to the following information:
.RS
.TP
\fBgeomap::awips::state::\fIID\fR
A linearray created with the \fBgeomap::lnarr\fR command (see the
\fBtclgeomap\fR (n) man page) containing state boundary.
.TP
\fBgeomap::awips::state::name(\fIID\fR)
Array element giving the full name of the state.
.TP
\fBgeomap::awips::state::center::\fIID\fR
A place created with the \fBgeomap::place\fR command (see the \fBtclgeomap\fR
(n) man page) giving coordinates of a place inside the state, giving a rough
idea of its location.
.TP
\fBgeomap::awips::state::states\fR
List of identifiers for loaded states.
.RE
.RE

.RS
Return value is the number of states loaded.
.RE
.SH FILES
\fBawips.tcl\fR
.SH AUTHOR
Gordon Carrie <tkgeomap@users.sourceforge.net>
