.\" 
.\" Copyright (c) 2003, 2004 Gordon D. Carrie.  All rights reserved.
.\" 
.\" Licensed under the Open Software License version 2.1
.\" 
.\" Please address questions and bug reports to user0@tkgeomap.org.
.\"
.\" @(#) $Id: geomap_census_gaz.n,v 1.5 2004/09/22 22:37:16 tkgeomap Exp $
.\"
.TH geomap_census_gaz n 2 Tcl "Tcl Extensions geomap_census_gaz"
.SH NAME
geomap_census_gaz \- package to access NWS/AWIPS map data with Tcl/Tkgeomap
.SH VERSION
2
.SH SYNOPSIS
.nf
\fBpackage require geomap_census_gaz ?2?\fR
.sp
\fBgeomap::us_census::gaz::read\fR \fIinFile\fR ?\fIverbose\fR?
\fBgeomap::us_census::gaz::read_sorted\fR \fIinFile\fR
\fBgeomap::us_census::gaz::popcmp\fR \fIp1 p2\fR
\fBgeomap::us_census::gaz::regexp\fR \fIexp\fR ?\fInocase\fR?
\fBgeomap::us_census::gaz::smallest\fR \fIminPop\fR
.fi
.SH INTRODUCTION
The \fBgeomap_census_gaz\fR package accesses data obtained from the U.S. Census
gazetteer, availabe at http://www.census.gov/geo/www/gazetteer/places2k.html.
.PP
The package requires \fBtcl/tk\fR from http://dev.scriptics.com, version 8.3 or
later, and \fBtkgeomap\fR, a Tcl/Tk extension to Tcl/TK, from
http://tkgeomap.sourceforge.net.
.SH PROCEDURES
.TP
\fBgeomap::us_census::gaz::read\fR \fIinFile\fR ?\fIverbose\fR?
.RS
Reads U.S. Census gazetteer data.  \fIinFile\fR should be a copy of
http://www.census.gov/tiger/tms/gazetteer/places2k.txt.  If the \fIverbose\fR
option is present and has a Boolean value of true, the procedure prints progress
and status information to the terminal.
.RE
.RS
Each place loaded will be identified by its FIPS code.  The following
information will be recorded:
.RS
.TP
\fBgeomap::us_census::gaz::type(\fIfips\fR)
Array element giving the type of place, e.g. "city", "town", "CDP".
.TP
\fBgeomap::us_census::gaz::name(\fIfips\fR)
Array element giving the place name.
.TP
\fBgeomap::us_census::gaz::state(\fIfips\fR)
Array element giving the two-letter abbreviation for the state the place is in.
.TP
\fBgeomap::us_census::gaz::pop(\fIfips\fR)
Array element giving the place population.
.TP
\fBgeomap::us_census::gaz::places\fR
List of place identifiers, sorted from most populous to least.
.TP
\fBgeomap::us_census::gaz::n_places\fR
Same as the \fBplaces\fR list, except that the identifiers are fully qualified.
.TP
\fBgeomap::us_census::gaz::types\fR
List of place types.
.RE
.RE
.RS
Result is the number of places loaded.
.RE
.TP
\fBgeomap::us_census::gaz::read_sorted\fR \fIinFile\fR
Reads place data from an optimized file.
\fIinFile\fR should contain place data from
http://www.census.gov/tiger/tms/gazetteer/places2k.txt, but with the places
sorted from most populous to least.  There should be one line for each place.
Each line should be a list of form:
.nf
\fIfips name state {lat lon} type population\fR
.fi
The data will go into the same arrays and lists used by the \fBread\fR
procedure.
.TP
\fBgeomap::us_census::gaz::popcmp\fR \fIp1 p2\fR
Compares two places by population.  \fIp1\fR and \fIp2\fR should be identifiers
for places loaded with the \fBread\fR or \fBread_sorted\fR procedure.  Return
value will be \fB-1\fR if the population of \fIp1\fR is less than the
population of \fIp2\fR, \fB0\fR if \fIp1\fR and \fIp2\fR have the same
population, or \fB1\fR if the population of \fIp1\fR is greater than the
population of \fIp2\fR.
.TP
\fBgeomap::us_census::gaz::regexp\fR \fIexp\fR ?\fInocase\fR?
Searches the \fBgeomap::us_census::gaz\fR namespace for places whose names
match regular expression pattern \fIexp\fR.  Result is a list of unqualified
place identifiers.
If \fInocase\fR is present and has a Boolean value of true, the search is
case insensitive.
.TP
\fBgeomap::us_census::gaz::smallest\fR \fIminPop\fR
Returns the index of the place in \fBgeomap::us_census::gaz::places\fR with
the smallest population that is still greater than \fIminPop\fR, or \fB-1\fR if
no place has a population greater than \fIminPop\fR.
.SH FILES
\fBcensus_gaz.tcl\fR
.SH AUTHOR
Gordon Carrie tkgeomap@users.sourceforge.net
