.\" 
.\" Copyright (c) 2003, 2004 Gordon D. Carrie.  All rights reserved.
.\" 
.\" Licensed under the Open Software License version 2.1
.\" 
.\" Please address questions and bug reports to user0@tkgeomap.org.
.\"
.\" @(#) $Id: geomap_usgs_gaz.n,v 1.4 2004/09/22 22:37:16 tkgeomap Exp $
.\"
.TH geomap_usgs_gaz n 2 Tcl "Tcl Extensions geomap_usgs_gaz"
.SH NAME
geomap_usgs_gaz \- package to access USGS gazetteeer data with Tcl/Tkgeomap
.SH VERSION
2
.SH SYNOPSIS
.nf
\fBpackage require geomap_usgs_gaz ?2?\fR
.sp
\fBgeomap::usgs::gaz::read\fR \fIinFile type\fR
\fBgeomap::usgs::gaz::\fItype\fB::regexp\fR \fIexp\fR ?\fInocase\fR?
.fi
.SH INTRODUCTION
The \fBgeomap_usgs_gaz\fR package accesses data obtained from the USGS
gazetteer, availabe at http://mapping.usgs.gov/www/gnis
.PP
The package requires \fBtcl/tk\fR from http://dev.scriptics.com, version 8.3 or
later, and \fBtkgeomap\fR, a Tcl/Tk extension to Tcl/TK, from
http://tkgeomap.sourceforge.net.
.SH PROCEDURES
.TP
\fBgeomap::usgs::gaz::read\fR \fIinFile\fR ?\fItype\fR?
.RS
Reads USGS gazetteer data.  \fIinFile\fR should be a gazetteer columnar file.
It can start with \fB|\fR to indicate data from a process.
\fItype\fR should be a place type.  To get a list of USGS place types, run
\fBcut -b 55-63 \fIfile1 ?file2 ...?\fB | sort -u\fR on the Unix command line,
where \fIfile1 ?file2 ...?\fR identifies one or more columnar format gazetteer
files.
.RE
.RS
The \fBread\fR procedure will create a namespace for the type called
\fBgeomap::usgs::gaz::\fItype\fR.  It will create a unique identifier for each place
in \fIinFile\fR of the given \fItype\fR, of form \fBp\fIXXX\fR, where \fIXXX\fR
is an integer.  The namespace will have the following information:
.RS
.TP
\fBgeomap::usgs::gaz::\fItype\fB::name(\fBp\fIXXX\fR)
Array element with place name.
.TP
\fBgeomap::usgs::gaz::\fItype\fB::county(\fBp\fIXXX\fR)
Array element with county that contains the place.
.TP
\fBgeomap::usgs::gaz::\fItype\fB::state(\fBp\fIXXX\fR)
Array element with state that contains the place.
.TP
\fBgeomap::usgs::gaz::\fItype\fB::elev(\fBp\fIXXX\fR)
Array element with place elevation.  Check the USGS web site for units.
.TP
\fBgeomap::usgs::gaz::\fItype\fB::p\fIXXX\fR
A place created with the \fBgeomap::place\fR command (see the \fBtclgeomap\fR
(n) man page) giving coordinates of a place.
.TP
\fBgeomap::usgs::gaz::\fItype\fB::places\fR
List of place identifiers.
.TP
\fBgeomap::usgs::gaz::\fItype\fB::n_places\fR
Same as \fBplaces\fR, except that identifiers are fully qualified.
.RE
.RE
.RS
Result is number of places in the type namespace.
.RE
.TP
\fBgeomap::usgs::gaz::\fItype\fB::regexp\fR \fIexp\fR ?\fInocase\fR?
This procedure searchs namespace \fBgeomap::usgs::gaz::\fItype\fR for places
whose names match regular expression \fIexp\fR.  If \fInocase\fR option is
present and has Boolean value true, the search is case insensitive.  Result is
a list of one or more place identifiers whose names match \fIexp\fR.
.SH FILES
\fBusgs_gaz.tcl\fR
